<template>
  <div v-if='dataSource.length'>
    <div :style="{ padding: '0 0 32px 32px' }">
      <h4 :style="{ marginTop: '20px' }" style='text-align: center'>{{ title }}</h4>
      <v-chart :forceFit='true'  :height='height' :data='dataSource'  :scale='scale' :padding='padding'  :onClick="handleClick" >
        <v-tooltip />
        <v-interval
          position='type*value'
          opacity='1'
          :label='barLabel'
          :size='26'
        >
        </v-interval>
        <v-axis
          dataKey='type'
          :label='label'
          :tickLine='tickLine'
          :line='line'
        >
        </v-axis>
        <v-coord type='rect' direction='LB'></v-coord>
        <v-axis
          dataKey='value'
          :label='null'
          :title='titleConfig'
        >
        </v-axis>
      </v-chart>
    </div>
  </div>
</template>

<script>
import { ChartEventMixins } from './mixins/ChartMixins'
import { triggerWindowResizeEvent } from '@/utils/util'
import { WEEKLY_LEFT_TOGGLE } from '@/vuebus/event-bus'


function sortData(sortType) {
  if (sortType === 'positive') {
    data.sort(function(a, b) {
      return b.value - a.value
    })
  } else {
    data.sort(function(a, b) {
      return a.value - b.value
    })
  }
}

export default {
  name: 'BarHorizontal',
  mixins: [ChartEventMixins],
  props: {
    dataSource: {
      type: Array,
      default: () => [],
      required: true
    },
    max: {
      type: Number,
      default: 10
    },
    title: {
      type: String,
      default: ''
    },
    height: {
      type: Number,
      default: 400
    }
  },
  watch: {
     height: {
    immediate: true,
    handler() {
      triggerWindowResizeEvent()
      console.info(this.height)
    },
  },
   /* dataSource: {
      immediate: true,
      handler() {
        this.height = this.dataSource.length * 40
        console.info(this.dataSource.length)
      },
    },*/
  },
  mounted() {
    this.$bus.$on(WEEKLY_LEFT_TOGGLE, () => {
      triggerWindowResizeEvent()
    })
  },
  methods: {

  },
  data() {
    return {
      sortType: 'negative',
      padding: [20, 60, 50, 100],
      scale:[{
        dataKey: 'value',

        min: 0,
        nice: false,
        alias: '工时（h）'
      }],
      label:{
        textStyle: {
          fill: '#8d8d8d',
          fontSize: 12
        }
      },
      barLabel:['value', {
        textStyle: {
          fill: '#8d8d8d'
        },
        offset: 10
      }],
      tickLine:{
        alignWithLabel: false,
        length: 0
      },
      titleConfig:{
        offset: 30,
        textStyle: {
          fontSize: 12,
          fontWeight: 300
        }
      },
      line:{
        lineWidth: 0
      }
    }
  },
  beforeDestroy() {
    this.$bus.$off(WEEKLY_LEFT_TOGGLE)
  }
}
</script>

